%define anolis_release 1
%bcond_with tests

# This bcond allows to ship a non-compiled version
# Slower, but sometimes necessary with alpha Python versions
%bcond_without cython_compile

Name:           Cython
Version:        3.0.10
Release:        %{anolis_release}%{?dist}
Summary:        Language for writing Python extension modules

License:        ASL 2.0
URL:            http://www.cython.org
Source:         https://github.com/cython/cython/archive/%{version}/Cython-%{version}.tar.gz

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

%if %{with tests}
BuildRequires:  gcc-c++
BuildRequires:  python3-numpy
BuildRequires:  python3-jedi
%endif

%if %{with cython_compile}
BuildRequires:  gcc
%global python3_site %{python3_sitearch}
%else
BuildArch:      noarch
%global python3_site %{python3_sitelib}
%endif

%global _description %{expand:
The Cython language makes writing C extensions for the Python language as easy
as Python itself. Cython is a source code translator based on Pyrex,
but supports more cutting edge functionality and optimizations.

The Cython language is a superset of the Python language (almost all Python
code is also valid Cython code), but Cython additionally supports optional
static typing to natively call C functions, operate with C++ classes and
declare fast C types on variables and class attributes.
This allows the compiler to generate very efficient C code from Cython code.

This makes Cython the ideal language for writing glue code for external C/C++
libraries, and for fast C modules that speed up the execution of Python code.}

%description %{_description}


%package -n python3-Cython
Summary:        %{summary}
Provides:       Cython = %{version}-%{release}
Provides:       cython = %{version}-%{release}
%py_provides    python3-cython

# A small templating library is bundled in Cython/Tempita
# Upstream version 0.5.2 is available from https://pypi.org/project/Tempita
# but the bundled copy is patched and reorganized.
# Upstream homepage is inaccessible.
Provides:       bundled(python3dist(tempita))

%description -n python3-Cython %{_description}

%package -n python3-Cython-doc
Summary:        %{summary}
BuildArch:      noarch
Requires:	python3-Cython = %{version}-%{release}

%description -n python3-Cython-doc %{_description}
This package contains documentation for %{name}.

%prep
%autosetup -n cython-%{version} -p1


%build
%py3_build -- %{!?with_cython_compile:--no-cython-compile}

%install
%py3_install -- %{!?with_cython_compile:--no-cython-compile}

%if %{with tests}
%check
%{python3} runtests.py -vv --no-pyregr %{?_smp_mflags}
%endif


%files -n python3-Cython
%license LICENSE.txt
%{_bindir}/cython
%{_bindir}/cygdb
%{_bindir}/cythonize
%{python3_site}/Cython-*.egg-info/
%{python3_site}/Cython/
%{python3_site}/pyximport/
%pycached %{python3_site}/cython.py

%files -n python3-Cython-doc
%doc *.txt Demos Doc Tools

%changelog
* Fri Nov 01 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.0.10-1
- update to 3.0.10 for python-scikit-learn

* Mon Mar 11 2024 Bo Ren <rb01097748@alibaba-inc.com> - 0.29.32-3
- Rebuild with python3.11

* Mon Mar 27 2023 happy_orange <songnannan@linux.alibaba.com> - 0.29.32-2
- add doc packages and disable check

* Fri Jan 27 2023 Funda Wang <fundawang@yeah.net> - 0.29.32-1
- Import package for anolis 23
